<?php
// ----------------------------------------------------------------------
// File: $Id: vkpmodules.php,v 1.2.2.2 2004/01/17 22:37:31 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkpmodules.php
 *
 * Diese Datei enthlt die Klassen vkpModule und vkpModules.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage API (Klassen)
 * @category Module
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * __VKP_MODULES_INSTANCE
 *
 * Der Name der globalen Variablen, die die Instance enthlt.
 *
 * @access private
 * @see vkpModules
 */
define('__VKP_MODULES_INSTANCE', '__vkp_modules_instance');

/**
 * Klasse vkpModule
 *
 * Diese Klasse enthlt die Eigenschaften und Methoden eines einzelnen
 * Modules.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpModule
{
    /**
     * vkpModule
     *
     * Der Konstruktor.
     *
     * @access protected
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function vkpModule($source)
    {
        if (empty($source) || !is_array($source) || !array_key_exists('mid', $source))
            die('Internal error in vkpModule::vkpModule()! ' . __FILE__ . ', line: ' . __LINE__);
        foreach ($source as $name => $value)
            $this->$name = $value;
    }

    /**
     * Exists
     *
     * Prft, ob ein Modul berhaupt existiert.  Dazu muss die Datei 'index.php'
     * im Modulverzeichnis vorhanden sein.  Wenn ein Dateiname angegeben wird, dann
     * wird ausschlielich dieser berprft.
     *
     * @param string $file Der Dateiname des Moduls
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function Exists($file = 'index')
    {
        $filename = $this->GetFilename($file, true);
        $result = file_exists($filename);
        return $result;
    }

    /**
     * GetFilename
     *
     * Prft, ob eine Datei des Moduls existiert.  Dazu muss die Datei 'index.php'
     * im Modulverzeichnis vorhanden sein.
     *
     * @param string $file Der Dateiname des Moduls
     * @param bool $absolute Vollstndiger Pfadname (oder bezogen auf Web-Root)
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function GetFilename($file, $absolute = false)
    {
        if ($absolute)
            $result = VKP_BASE_DIR . '/';
        else
            $result = '';
        $result .=  'modules/' . vkpVarPrepForOs($this->title) . '/' . vkpVarPrepForOs($file) . '.php';
        return $result;
    }

    /**
     * GetUri
     *
     * Liefert die relative Uri auf das Modul.
     *
     * @param string $file Der Dateiname des Moduls
     * @param bool $absolute Vollstndiger Pfadname (oder bezogen auf Web-Root)
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function GetUri($file = '')
    {
        $result = 'modules.php?name=' . $this->title;
        if (!empty($file))
            $result .= '&amp;file=' . $file;
        return $result;
    }

    /**
     * LoadFile
     *
     * Diese Methode ld eine Modulkomponente.  Im Normalfall sollte diese
     * Methode nicht benutzt werden, da es spezialisierte Methoden fr die
     * einzelnen Komponenten gibt.
     *
     * @param string $name Der Komponentenname (ohne .php)
     * @return bool TRUE, wenn geladen
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpModule::LoadApi(), vkpModule::LoadLibrary(), vkpModule::LoadUserNavigation()
     */
    function LoadFile($name)
    {
        if (empty($name))
            return false;
        $filename = $this->GetFilename(vkpVarPrepForStore($name),
                                       true);
        if (!file_exists($filename))
            return false;

        require_once $filename;
        return true;
    }

    /**
     * LoadLibrary
     *
     * Ld die Bibliothek des Moduls.  Die Bibliothek ist optional.  Sie
     * befindet sich im Modulverzeichnis unter dem Namen vkplibrary.php.
     * Eine Bibliothek enthlt Low-Level-Funktionen und -klassen, die keine
     * Rcksicht auf Zugriffsberechtigungen nimmt.
     *
     * @return bool TRUE, wenn eine Bibliothek vorhanden ist
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpModule::LoadFile(), vkpModule::LoadApi(), vkpModule::LoadUserNavigation()
     */
    function LoadLibrary()
    {
        $result = $this->LoadFile('vkplibrary');
        return $result;
    }

    /**
     * LoadApi
     *
     * Ld die API eines Moduls.  Die API befindet sich im Modulverzeichnis
     * und hat den Dateinamen vkpapi.php.  Eine API ist optional. Wenn sie
     * implementiert ist, muss sie die Zugriffsberechtigung bercksichtigen.
     *
     * @return bool TRUE, wenn eine API geladen wurde
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpModule::LoadFile(), vkpModule::LoadLibrary(), vkpModule::LoadUserNavigation()
     */
    function LoadApi()
    {
        $result = $this->LoadFile('vkpapi');
        return $result;
    }

    /**
     * LoadUserNavigation
     *
     * Wenn ein Modul ber eine eigene User-Navigation verfgt, dann wird diese
     * durch diese Metzhode geladen.
     *
     * @return bool TRUE, wenn die Navigation geladen wurde
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     * @see vkpModule::LoadFile(), vkpModule::LoadLibrary(), vkpModule::LoadApi()
     */
    function LoadUserNavigation()
    {
        $result = $this->LoadFile('vkpusernav');
        return $result;
    }
}

/**
 * Klasse vkpModules
 *
 * Diese Klasse enthlt die Liste aller Module sowie eine Reihe von
 * Hilfsmethoden.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpModules
{
    /**
     * vkpModules
     *
     * Konstruktor.
     *
     * @access protected
     * @see vkpModules::GetInstance()
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function vkpModules()
    {
        $config =& vkpConfig::GetInstance();
        $sql = "SELECT t1.mid,
                       t1.title,
                       t1.custom_title,
                       t1.active,
                       t1.view,
                       (t1.title=t2.main_module) AS `main`
                FROM `" . $config->prefix . "_modules`  t1,
                     `" . $config->prefix . "_main`     t2
                ORDER BY t1.title ASC";

        // Alle Datenstze laden
        //
        if (false === ($dbr = sql_query($sql)))
            vkpDie('Unable to access the database!');
        while ($item = sql_fetch_array($dbr))
            $this->$item['title'] =& new vkpModule($item);
        $dbr->Free();
    }

    /**
     * GetInstance
     *
     * Liefert die Instanz dieser Klasse.
     *
     * @return vkpModules Die Referenz zur Instanz
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function &GetInstance()
    {
        if (!array_key_exists(__VKP_MODULES_INSTANCE, $GLOBALS) || !is_a($GLOBALS[__VKP_MODULES_INSTANCE], 'vkpModules'))
            $GLOBALS[__VKP_MODULES_INSTANCE] =& new vkpModules();
        return $GLOBALS[__VKP_MODULES_INSTANCE];
    }

    /**
     * GetAll
     *
     * Liefert alle Module zurck.
     *
     * @return array
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function GetAll()
    {
        $result = array();
        foreach ($this as $name => $value)
            $result[$name] = $value;
        return $result;
    }

    /**
     * GetMain
     *
     * Liefert das Startmodul zurck
     *
     * @return vkpModule
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function &GetMain()
    {
        foreach ($this as $name => $value)
        {
            if (!$this->$name->main)
                continue;

            return $this->$name;
        }
        return false;
    }
    /**
     * Get
     *
     * Liefert die Instanz eines bestimmten Moduls.
     *
     * @param string $name Der Name des Moduls
     * @return vkpModule Die Instanz
     * @author Hinrich Donner
     * @since 5.5.1
     * @version 0.1
     */
    function &Get($name)
    {
        if (!empty($name) && isset($this->$name))
            return $this->$name;
        return null;
    }

}

/**
 * vkpModuleFrame
 *
 * Diese Klasse stellt die Basis fr OOP-Module des VKP dar.
 *
 * @abstract
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
class vkpModuleFrame
{
    /**
     * admin
     *
     * Eine Reference auf die Instanz mit den Informationen des angemeldeten
     * Administrators.
     *
     * @var vkpAdmin
     */
    var $admin;

    /**
     * config
     *
     * Eine Referenz zu der Instanz mit der Konfiguration.
     *
     * @var vkpConfig
     */
    var $config;

    /**
     * modulename
     *
     * Der physikalische Name des Modules.
     *
     * @var string
     */
    var $modulename;

    /**
     * moduletitle
     *
     * Der Titel des Moduls
     *
     * @var string
     */
    var $moduletitle = '';

    /**
     * user
     *
     * Eine Referenz zur Instanz mit den Userdaten.
     *
     * @var vkpUser
     */
    var $user;

    /**
     * vkpModuleFrame
     *
     * Der Konstruktor.
     *
     * @param string $modulename Der physikalische Name des Moduls
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function vkpModuleFrame($modulename)
    {
        $this->config       =& vkpConfig::GetInstance();
        $this->admin        =& vkpAdmin::GetInstance();
        $this->user         =& vkpUser::GetInstance();
        $this->modulename   = $modulename;
        get_lang($modulename);
    }

    /**
     * Header
     *
     * Startet die Ausgabe.  Dabei werden alle sonst manuell vorgegebenen Daten
     * fr die header.php aufbereitet, bevor diese tatschlich geladen wird.
     *
     * @param string $moduletitle Der Titel des Moduls
     * @param string $subtitle Ein Untertitel
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function Header($moduletitle, $subtitle = '')
    {
        global $pagetitle;

        // Titel zusammensetzen
        //
        $this->moduletitle  = $moduletitle;
        $my_title = $this->moduletitle;
        if (!empty($subtitle))
            $my_title .= ': ' . $subtitle;
        $pagetitle .= ' - ' . $my_title;

        // Ausgabe starten
        //
        include 'header.php';

        // Titel anzeigen
        //
        title($my_title);
    }

    /**
     * Footer
     *
     * Beendet den Ausgabeteil.
     *
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function Footer()
    {
        include 'footer.php';
    }
}

// $Log: vkpmodules.php,v $
// Revision 1.2.2.2  2004/01/17 22:37:31  hdonner
// - Klasse vkpModuleFrame
//
// Revision 1.2.2.1  2004/01/11 18:35:18  hdonner
// - Fix: #1341
//
// Revision 1.2  2004/01/10 11:30:27  hdonner
// - Vorbereiten fr Modul-Bibliotheken
//
// Revision 1.1  2003/12/17 17:39:36  hdonner
// - Modulhandler in OOP
//
//
?>
