<?php
// ----------------------------------------------------------------------
// File: $Id: nukeapi.php,v 1.10.2.1 2004/01/11 18:35:44 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * nukeapi.php
 *
 * Diese Datei enthlt die Funktionen, die man zur API zhlen knnte,
 * wenn man diesen Begriff verwenden mchte.
 *
 * @author Hinrich Donner
 * @author F. Bruzi
 * @version 0.1
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage API
 * @category PHP-Nuke-Kompatibilitt
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * get_lang
 *
 * Ld die Sprachdatei fr ein Modul.
 *
 * @param string $module
 * @return bool TRUE, wenn die Sprache geladen wurde, oder FALSE bei Fehlern
 * @author Hinrich Donner
 */
function get_lang($module)
{
    global $currentlang;

    $filename = (($module == 'admin')
                ? 'admin/language/lang-' . vkpVarPrepForOs($currentlang) . '.php'
                : 'modules/' . vkpVarPrepForOs($module) . '/language/lang-' . vkpVarPrepForOs($currentlang) . '.php');

    if (file_exists($filename))
    {
        include_once $filename;
        return true;
    }

    // Fallback auf die Default-Sprache, falls eine andere gewhlt wurde.
    //
    $config =& vkpConfig::GetInstance();

    if ($currentlang == $config->language)
        return false;

    $filename = (($module == 'admin')
                ? 'admin/language/lang-' . vkpVarPrepForOs($config->language) . '.php'
                : 'modules/' . vkpVarPrepForOs($module) . '/language/lang-' . vkpVarPrepForOs($config->language) . '.php');

    if (file_exists($filename))
    {
        include_once $filename;
        return true;
    }

    return false;
}

/**
 * is_admin
 *
 * Testet, ob der aktuelle Benutzer als Administrator angemeldet ist.
 *
 * @param mixed $admin Base64 kodierter String oder ein Array
 * @return bool
 * @author Hinrich Donner
 * @version 0.3
 * @since 5.5.1
 * @see is_user()
 */
function is_admin($admin)
{
    static $result;
    if (!isset($result))
        $result = vkpAdminLoggedIn();
    return $result;
}

/**
 * is_user
 *
 * Testet, ob der aktuelle Benutzer angemeldet ist.
 *
 * @param mixed $user Ein base64 kodierter String oder ein Array
 * @return bool
 * @author Hinrich Donner
 * @version 0.3
 * @since 5.5.1
 * @see is_admin()
 */
function is_user($user)
{
    static $result;
    if (isset($result))
        return $result;
    $result = vkpUserLoggedIn();
    return $result;
}

/**
 * is_active
 *
 * Testet, ob das namentlich angegebene Modul aktiv ist.
 *
 * @param string $modulename Der Name
 * @return bool
 * @author Hinrich Donner
 * @version 0.2
 * @since 5.5.1
 */
function is_active($modulename)
{
    return vkpModuleIsActive($modulename);
}

/**
 * blocks
 *
 * Stellt die Blcke fr eine angegebene Region ($side) dar. Die Region kann
 * 'left', 'right', 'center' oder 'down' sein, wobe 'center' oben und 'down'
 * unten im Arbeitsbereich kennzeichnet. Die tatschliche Darstellung hngt
 * vom Theme ab.
 *
 * @param string $side Die Region
 * @author F. Bruzi
 * @author Hinrich Donner
 * @version 0.2
 * @since 5.5.1
 */
function blocks($side)
{
    global $currentlang;

    // Konfigurationsinstanz
    //
    $config =& vkpConfig::GetInstance();

    // Leere Angaben sind nicht zulssig
    //
    if (strlen($side) < 1)
        return;

    // SQL-WHERE-Anweisung vorbereiten
    //
    $where = array("`active`='1'");

    // Region hinzufgen
    //
    $where[] = "`position`='" . vkpVarPrepForStore(strtolower(substr($side, 0, 1))) . "'";

    // Mehrsprachigkeit festlegen
    //
    if ($config->multilingual == 1)
        $querylang = "AND (`blanguage`='" . vkpVarPrepForStore($currentlang) . "' OR `blanguage`='')";

    // SQL zusammensetzen
    //
    $sql = "SELECT `bid`,
                   `bkey`,
                   `title`,
                   `content`,
                   `url`,
                   `blockfile`,
                   `view`
            FROM `" . $config->prefix . "_blocks`
            WHERE (" . join(' AND ', $where) . ")
            ORDER BY `weight` ASC";

    // SQL ausfhren
    //
    $dbr = sql_query($sql);
    while ($block = sql_fetch_array($dbr))
    {
        if ($block['bkey'] == 'admin')
            adminblock();

        elseif ($block['bkey'] == 'userbox')
            userblock();
        elseif (empty($bkey))
        {
            if (($block['view'] == 0)
                    || ($block['view'] == 1 AND vkpUserLoggedIn() || vkpAdminLoggedIn())
                    || ($block['view'] == 2 AND vkpAdminLoggedIn())
                    || ($block['view'] == 3 AND !vkpUserLoggedIn() || vkpAdminLoggedIn()))
                render_blocks(strtolower(substr($side, 0, 1)),
                              $block['blockfile'],
                              $block['title'],
                              $block['content'],
                              $block['bid'],
                              $block['url']);
        }
    }
}

/**
 * message_box
 *
 * Stellt die Mitteilingsboxen dar.
 *
 * @author F. Bruzi
 * @author Hinrich Donner
 * @version 0.2
 * @since 5.5.1
 */
function message_box()
{
    global $bgcolor1, $bgcolor2, $textcolor2, $currentlang;

    $config =& vkpConfig::GetInstance();

    if ($config->multilingual == 1)
        $querylang = "AND (`mlanguage`='$currentlang' OR `mlanguage`='')";
    else
        $querylang = '';

    $result = sql_query("SELECT `mid`,
                                `title`,
                                `content`,
                                `date`,
                                `expire`,
                                `view`
                         FROM `" . $config->prefix . "_message`
                         WHERE `active`='1' $querylang");
    if (sql_num_rows($result) == 0)
        return;

    while (list($mid, $title, $content, $mdate, $expire, $view) = sql_fetch_row($result))
    {
        if (!empty($title) && !empty($content))
        {
            if ($expire == 0)
                $remain = _UNLIMITED;
            else
            {
                $etime = (($mdate + $expire) - time()) / 3600;
                $etime = (int) $etime;
                if ($etime < 1)
                    $remain = _EXPIRELESSHOUR;
                else
                    $remain = '' . _EXPIREIN . " $etime " . _HOURS;
            }

            if (($view == 4) && vkpAdminLoggedIn())
            {
                OpenTable();
                echo "<div align=\"left\">"
                    . "<span class=\"option\" color=\"$textcolor2\"><b>$title</b>"
                    . "</span>"
                    . "</div>\n"
                    . "<br>\n"
                    . "<div align=\"left\">"
                    . "<span class=\"content\">$content</span>"
                    . "</div>\n"
                    . "<br><br>\n"
                    . "<div align=\"center\"><span class=\"content\">[ "
                    . _MVIEWADMIN . " - $remain - <a href=\"admin.php?op=editmsg&amp;mid=$mid\">"
                    . _EDIT . "</a> ]</span></div>\n";
                CloseTable();
                echo "<br>\n";
            }
            elseif (($view == 3) && (vkpUserLoggedIn() || vkpAdminLoggedIn()))
            {
                OpenTable();
                echo "<div align=\"center\">"
                    . "<span class=\"option\" color=\"$textcolor2\"><b>$title</b>"
                    . "</span>"
                    . "</div>\n"
                    . "<br>\n"
                    . "<div align=\"left\">"
                    . "<span class=\"content\">$content</span>"
                    . "</div>\n";
                if (vkpAdminLoggedIn())
                    echo "<br><br>\n"
                        . "<div align=\"center\"><span class=\"content\">[ "
                        . _MVIEWUSERS . " - $remain - <a href=\"admin.php?op=editmsg&amp;mid=$mid\">"
                        . _EDIT . "</a> ]</span></div>\n";
                CloseTable();
                echo "<br>\n";
            }
            elseif (($view == 2) && (!vkpUserLoggedIn() || vkpAdminLoggedIn()))
            {
                OpenTable();
                echo "<div align=\"center\">"
                    . "<span class=\"option\" color=\"$textcolor2\"><b>$title</b>"
                    . "</span>"
                    . "</div>\n"
                    . "<br>\n"
                    . "<div align=\"left\">"
                    . "<span class=\"content\">$content</span>"
                    . "</div>\n";
                if (vkpAdminLoggedIn())
                    echo "<br><br>\n"
                        . "<div align=\"center\"><span class=\"content\">[ "
                        . _MVIEWANON . " - $remain - <a href=\"admin.php?op=editmsg&amp;mid=$mid\">"
                        . _EDIT . "</a> ]</span></div>\n";
                CloseTable();
                echo "<br>\n";
            }
            elseif ($view == 1)
            {
                OpenTable();
                echo "<div align=\"center\">"
                    . "<span class=\"option\" color=\"$textcolor2\"><b>$title</b>"
                    . "</span>"
                    . "</div>\n"
                    . "<br>\n"
                    . "<div align=\"left\">"
                    . "<span class=\"content\">$content</span>"
                    . "</div>\n";
                if (vkpAdminLoggedIn())
                    echo "<br><br>\n"
                        . "<div align=\"center\"><span class=\"content\">[ "
                        . _MVIEWALL . " - $remain - <a href=\"admin.php?op=editmsg&amp;mid=$mid\">"
                        . _EDIT . "</a> ]</span></div>\n";
                CloseTable();
                echo "<br>\n";
            }
            // Prfe, ob die Zeit abgelaufen ist.
            //
            if ($expire != 0)
            {
                $past = time()-$expire;
                if ($mdate < $past)
                    sql_query("UPDATE `".$prefix."_message`
                               SET `active`='0'
                               WHERE `mid`='$mid'");
            }
        }
    }
}

/**
 * cookiedecode
 *
 * Decodiert das User-Cookie. Diese Funktion sollte nicht verwendet werden, denn
 * sie ist aufgrund der Seiteneffekte reines Gift.
 *
 * @param mixed $user Das Array mit den Details aus dem User-Cookie oder das kodierte User-Cookie
 * @return array Dekodiertes Cookie
 * @author F. Bruzi
 * @version 0.3
 * @since 5.5.1
 */
function cookiedecode()
{
    if (!vkpUserLoggedIn())
        return;

    global $cookie;

    if (isset($cookie))
        return $cookie;

    // Cookie simulieren
    //
    $userdata = vkpUserGetAllData();
    extract($userdata);
    $cookie = array($uid,
                    $uname,
                    $pass,
                    $storynum,
                    $umode,
                    $uorder,
                    $thold,
                    $noscore,
                    $ublockon,
                    $theme,
                    $commentmax);
    return $cookie;
}

/**
 * getusrinfo
 *
 * Liefert alle Informationen zum Benutzer aus der Datenbank.
 *
 * @param string $user Das User-Cookie, Base 64 kodiert.
 * @return array Alle Details oder FALSE
 * @author F. Bruzi
 * @version 0.3
 * @since 5.5.1
 */
function getusrinfo($user)
{
    if (!vkpUserLoggedIn())
        return;

    global $userinfo;

    if (isset($userinfo))
        return $userinfo;

    $user       =& vkpUser::GetInstance();
    $userinfo   = $user->details;
    return $userinfo;
}

/**
 * filter_text
 *
 * Filtert den Text. Diese Funktion ist aufgrund der extremen Seiteneffekte
 * zu vermeiden!!!
 *
 * @param string $Message Der Text
 * @param string $strip Wenn der Wert 'nohtml' lautet, wird jeder HTML-Code entfernt.
 * @return string Der gefilterte Text
 * @author F. Bruzi
 * @version 0.1
 * @since 5.5.1
 */
function filter_text($Message, $strip = "")
{
    global $EditedMessage;
    check_words($Message);
    $EditedMessage = check_html($EditedMessage, $strip);
    return $EditedMessage;
}

/**
 * check_words
 *
 * Prft einen Text auf verbotene Wrter und entfernt diese. Diese Funktion ist
 * aufgrund der extremen Seiteneffekte zu vermeiden!!!
 *
 * @param string $Message Der Text
 * @return string Der gefilterte Text
 * @author F. Bruzi
 * @version 0.2
 * @since 5.5.1
 */
function check_words($Message)
{
    global $EditedMessage;
    $config =& vkpConfig::GetInstance();
    $EditedMessage = $Message;
    if ($config->CensorMode != 0)
    {
        if (is_array($config->CensorList))
        {
            $Replace =& $config->CensorReplace;
            $CensorList =& $config->CensorList;
            if ($config->CensorMode == 1)
            {
                for ($i = 0; $i < count($CensorList); $i++)
                {
                    $EditedMessage = eregi_replace("$CensorList[$i]([^a-zA-Z0-9])","$Replace\\1",$EditedMessage);
                }
            }
            elseif ($config->CensorMode == 2)
            {
                for ($i = 0; $i < count($CensorList); $i++)
                {
                    $EditedMessage = eregi_replace("(^|[^[:alnum:]])$CensorList[$i]","\\1$Replace",$EditedMessage);
                }
            }
            elseif ($config->CensorMode == 3)
            {
                for ($i = 0; $i < count($CensorList); $i++)
                {
                    $EditedMessage = eregi_replace("$CensorList[$i]","$Replace",$EditedMessage);
                }
            }
        }
    }
    return ($EditedMessage);
}

/**
 * FixQuotes
 *
 * Soll das Problem mit magic_quotes_* bereinigen, tut es aber nicht.
 *
 * @param string $what Der Text
 * @return string Bereinigter Text
 * @author F. Bruzi
 * @version 0.1
 * @since 5.5.1
 */
function FixQuotes($what = "")
{
    $what = ereg_replace("'","''",$what);
    while (eregi("\\\\'", $what)) {
        $what = ereg_replace("\\\\'","'",$what);
    }
    return $what;
}

/**
 * delQuotes
 *
 * Der Name irritiert. Eigentlich sollen Quotes im HTML hinzugefgt werden, wenn
 * es notwendig ist, und berflssige White Spaces entfernt werden. Der Nutzen
 * tendiert gegen Null, so dass die Funktion zu vermeiden ist.
 *
 * @param string $string Der Text
 * @return string Bereinigter Text
 * @author F. Bruzi
 * @version 0.1
 * @since 5.5.1
 */
function delQuotes($string)
{
    /* no recursive function to add quote to an HTML tag if needed */
    /* and delete duplicate spaces between attribs. */
    $tmp="";    # string buffer
    $result=""; # result string
    $i=0;
    $attrib=-1; # Are us in an HTML attrib ?   -1: no attrib   0: name of the attrib   1: value of the atrib
    $quote=0;   # Is a string quote delimited opened ? 0=no, 1=yes
    $len = strlen($string);
    while ($i<$len) {
    switch($string[$i]) { # What car is it in the buffer ?
        case "\"": #"       # a quote.
        if ($quote==0) {
            $quote=1;
        } else {
            $quote=0;
            if (($attrib>0) && ($tmp != "")) { $result .= "=\"$tmp\""; }
            $tmp="";
            $attrib=-1;
        }
        break;
        case "=":           # an equal - attrib delimiter
        if ($quote==0) {  # Is it found in a string ?
            $attrib=1;
            if ($tmp!="") $result.=" $tmp";
            $tmp="";
        } else $tmp .= '=';
        break;
        case " ":           # a blank ?
        if ($attrib>0) {  # add it to the string, if one opened.
            $tmp .= $string[$i];
        }
        break;
        default:            # Other
        if ($attrib<0)    # If we weren't in an attrib, set attrib to 0
        $attrib=0;
        $tmp .= $string[$i];
        break;
    }
    $i++;
    }
    if (($quote!=0) && ($tmp != "")) {
    if ($attrib==1) $result .= "=";
    /* If it is the value of an atrib, add the '=' */
    $result .= "\"$tmp\"";  /* Add quote if needed (the reason of the function ;-) */
    }
    return $result;
}

/**
 * check_html
 *
 * berprft HTML auf ihre Erlaubnis. Diese Funktion ist
 * aufgrund der extremen Seiteneffekte zu vermeiden!!!
 *
 * @param string $str Der Text
 * @param string $strip '' oder 'nohtml'
 * @return string Bereinigter Text
 * @author F. Bruzi
 * @version 0.2
 * @since 5.5.1
 */
function check_html ($str, $strip="")
{
    /* The core of this code has been lifted from phpslash */
    /* which is licenced under the GPL. */
    $config =& vkpConfig::GetInstance();
    if ($strip == "nohtml")
        $config->AllowableHTML=array('');
    $str = stripslashes($str);
    $str = eregi_replace("<[[:space:]]*([^>]*)[[:space:]]*>",
                         '<\\1>', $str);
               // Delete all spaces from html tags .
    $str = eregi_replace("<a[^>]*href[[:space:]]*=[[:space:]]*\"?[[:space:]]*([^\" >]*)[[:space:]]*\"?[^>]*>",
                         '<a href="\\1">', $str); # "
               // Delete all attribs from Anchor, except an href, double quoted.
    $str = eregi_replace("<img?",
                         '', $str); # "
    $tmp = "";
    while (ereg("<(/?[[:alpha:]]*)[[:space:]]*([^>]*)>",$str,$reg)) {
        $i = strpos($str,$reg[0]);
        $l = strlen($reg[0]);
        if ($reg[1][0] == "/") $tag = strtolower(substr($reg[1],1));
        else $tag = strtolower($reg[1]);
        if ($a = $config->AllowableHTML[$tag])
            if ($reg[1][0] == "/") $tag = "</$tag>";
            elseif (($a == 1) || ($reg[2] == "")) $tag = "<$tag>";
            else {
              # Place here the double quote fix function.
              $attrb_list=delQuotes($reg[2]);
              // A VER
              $attrb_list = ereg_replace("&","&amp;",$attrb_list);
              $tag = "<$tag" . $attrb_list . ">";
            } # Attribs in tag allowed
        else $tag = "";
        $tmp .= substr($str,0,$i) . $tag;
        $str = substr($str,$i+$l);
    }
    $str = $tmp . $str;
    return $str;
    exit;
    /* Squash PHP tags unconditionally */
    $str = ereg_replace("<\?","",$str);
    return $str;
}

/*********************************************************/
/* formatting stories                                    */
/*********************************************************/

/**
 * formatTimestamp
 *
 * Formatiert einen Time Stamp.
 *
 * @param string $time ISO Zeitstring
 * @return string Formatierter Text
 * @author F. Bruzi
 * @version 0.2
 * @since 5.5.1
 */
function formatTimestamp($time)
{
    static $locale;

    if (!isset($locale))
    {
        $config =& vkpConfig::GetInstance();
        $locale = $config->locale;
        setlocale (LC_TIME, $locale);
    }

    global $datetime;

    ereg ("([0-9]{4})-([0-9]{1,2})-([0-9]{1,2}) ([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2})", $time, $datetime);
    $datetime = strftime(''._DATESTRING."", mktime($datetime[4],$datetime[5],$datetime[6],$datetime[2],$datetime[3],$datetime[1]));
    //$datetime = ucfirst($datetime);
    return $datetime;
}

/**
 * formatAidHeader
 *
 * Formatiert 'aid' und gibt ihn aus.
 *
 * @param string $aid Author ID
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 */
function formatAidHeader($aid)
{
    echo get_author($aid);
}

/**
 * get_author
 *
 * Formatiert 'aid'.
 *
 * @param string $aid Author ID
 * @return string Formated Author ID
 * @author F. Bruzi
 * @version 0.2
 * @since 5.5.1
 */
function get_author($aid)
{
    $config =& vkpConfig::GetInstance();

    $holder = sql_query("SELECT `url`, `email`
                         FROM `" . $config->prefix . "_authors`
                         WHERE `aid`='" . vkpVarPrepForStore($aid) . "'");
    if (!$holder)
        die(_ERROR);

    list($url,
         $email) = sql_fetch_row($holder);
    if (isset($url))
        $result = "<a href=\"$url\">$aid</a>";
    elseif (isset($email))
        $result = "<a href=\"mailto:$email\">$aid</a>";
    else
        $result = '' . $aid;

    return $result;
}

/**
 * adminblock
 *
 * Gibt den Admin-Block aus.
 *
 * @author Hinrich Donner
 * @author F. Bruzi
 * @version 0.2
 * @since 5.5.1
 */
function adminblock()
{
    $config =& vkpConfig::GetInstance();
    if (vkpAdminLoggedIn() && ($config->jdcache != 1))
    {
        $prefix = $config->prefix;
        $result = sql_query("SELECT `title`,
                                    `content`
                             FROM `" . $prefix . "_blocks`
                             WHERE `bkey`='admin'");
        while (list($title, $content) = sql_fetch_array($result))
        {
            $content = "<span class=\"content\">$content</span>";
            themesidebox($title, $content);
        }

        $content = "<span class=\"content\">";

        //$PHP_SELF =& $_SERVER['PHP_SELF'];

        // Prfen auf News
        //
        if(file_exists("modules/News/index.php"))
        {
            $title = ""._WAITINGCONT;
            $result = sql_query("SELECT COUNT(*) FROM `" . $prefix . "_queue`");
            list($num) = sql_fetch_row($result);
            $content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=submissions\">"._SUBMISSIONS."</a>: $num<br>";
        }

        // Prfen ob DB Eintraege vorhanden sind
        $query_downloads    = "SHOW TABLES LIKE '" . $prefix . "_downloads'";
        $query_links        = "SHOW TABLES LIKE '" . $prefix . "_links_links'";

        $sql_downloads      = sql_query($query_downloads);
        $sql_links          = sql_query($query_links);

        $ergebnis1          = sql_fetch_array($sql_downloads);
        $ergebnis2          = sql_fetch_array($sql_links);

        if ($ergebnis1[0] != '')
        {
            $num = vkpSqlRowCount($prefix . '_downloads_newdownload');
            $content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=downloads\">"._UDOWNLOADS."</a>: $num<br></font>";
        }
        if ($ergebnis2[0] != '')
        {
            $num = vkpSqlRowCount($prefix . '_links_newlink');
            $content .= "<strong><big>&middot;</big></strong>&nbsp;<a href=\"admin.php?op=Links\">"._WLINKS."</a>: $num<br>";
        }
        themesidebox($title, $content);
    }
}

/**
 * userblock
 *
 * Zeigt den userblock
 *
 * @author F. Bruzi
 * @version 0.3
 * @since 5.5.1
 */
function userblock()
{
    $user =& vkpUser::GetInstance();
    if (!$user->LoggedIn() || !$user->GetUBlockOn())
        return;
    themesidebox(_MENUFOR . ' ' . $user->GetUname(),
                 $user->GetUBlock());
}

/**
 * getTopics
 *
 * Liefert die Informationen zu einem Topic. Auch diese Funktion ist ein
 * Beispiel dafr, wie man es nicht machen sollte.
 *
 * @param int $s_sid Die ID des Artikels
 * @author F. Bruzi
 * @version 0.2
 * @since 5.5.1
 */
function getTopics($s_sid)
{
    static $prefix;

    if (!isset($prefix))
    {
        $config     =& vkpConfig::GetInstance();
        $prefix     = $config->prefix;
    }

    global $topicname, $topicimage, $topictext;

    $sid = vkpVarPrepForStore($s_sid);
    $result = sql_query("SELECT `topic` FROM `".$prefix."_stories` WHERE `sid`='$sid'");
    list($topic) = sql_fetch_row($result);
    $result = sql_query("SELECT `topicid`,
                                `topicname`,
                                `topicimage`,
                                `topictext`
                         FROM `".$prefix."_topics`
                         WHERE `topicid`='$topic'");
    list($topicid,
         $topicname,
         $topicimage,
         $topictext) = sql_fetch_row($result);
}

/**
 * headlines
 *
 * Stellt die RDF-Informationen dar.
 *
 * @author F. Bruzi
 * @version 0.1
 * @since 5.5.1
 */
function headlines($bid, $cenbox=0)
{
    $cont   = 0;
    $config =& vkpConfig::GetInstance();
    $result = sql_query("SELECT `title`,
                                `content`,
                                `url`,
                                `refresh`,
                                `time`
                         FROM `".$config->prefix."_blocks`
                         WHERE `bid`='" . vkpVarPrepForStore($bid) . "'");
    list($title,
         $content,
         $url,
         $refresh,
         $otime) = sql_fetch_row($result);
    $past = time()-$refresh;
    if ($otime < $past)
    {
        $btime = time();
        $rdf = parse_url($url);
        $fp = fsockopen($rdf['host'], 80, $errno, $errstr, 15);
        if (!$fp)
        {
            $content = "";
            //$content = "<font class=\"content\">"._RSSPROBLEM."</font>";
            $result = sql_query("UPDATE  `".$config->prefix."_blocks`
                                 SET `content`='" . vkpVarPrepForStore($content) . "',
                                     `time`='$btime'
                                 WHERE `bid`='" . vkpVarPrepForStore($bid) . "'");
            $cont = 0;
            if ($cenbox == 0)
                themesidebox($title, $content);
            else
                themecenterbox($title, $content);

            return;
        }
        if ($fp)
        {
            fputs($fp, "GET " . $rdf['path'] . "?" . $rdf['query'] . " HTTP/1.0\r\n");
            fputs($fp, "HOST: " . $rdf['host'] . "\r\n\r\n");
            $string = "";
            while(!feof($fp))
            {
                $pagetext = fgets($fp,300);
                $string .= chop($pagetext);
            }
            fputs($fp,"Connection: close\r\n\r\n");
            fclose($fp);
            $items = explode("</item>",$string);
            $content = "<font class=\"content\">";
            for ($i=0;$i<10;$i++)
            {
                $link = ereg_replace(".*<link>","",$items[$i]);
                $link = ereg_replace("</link>.*","",$link);
                $title2 = ereg_replace(".*<title>","",$items[$i]);
                $title2 = ereg_replace("</title>.*","",$title2);
                if ($items[$i] == "") {
                    $content = "";
                    sql_query("UPDATE ". $config->prefix."_blocks
                               SET content='" . vkpVarPrepForStore($content) . "',
                                   time='$btime'
                               WHERE bid='" . vkpVarPrepForStore($bid) . "'");
                    $cont = 0;
                    if ($cenbox == 0)
                        themesidebox($title, $content);
                    else
                        themecenterbox($title, $content);
                    return;
                }
                else
                {
                    if (strcmp($link,$title))
                    {
                        $cont = 1;
                        $content .= "<strong><big>&middot;</big></strong><a href=\"$link\" target=\"new\">$title2</a><br>\n";
                    }
                }
            }

        }
        sql_query("UPDATE ".$config->prefix."_blocks
                   SET content='" . vkpVarPrepForStore($content) . "',
                       time='$btime'
                   WHERE bid='" . vkpVarPrepForStore($bid) . "'");
    }
    $siteurl = ereg_replace("http://","",$url);
    $siteurl = explode("/",$siteurl);
    if (($cont == 1) OR ($content != ""))
        $content .= "<br><a href=\"http://$siteurl[0]\" target=\"blank\"><b>"._HREADMORE."</b></a></font>";
    elseif (($cont == 0) OR ($content == ""))
        $content = "<font class=\"content\">"._RSSPROBLEM."</font>";

    if ($cenbox == 0)
        themesidebox($title, $content);
    else
        themecenterbox($title, $content);
}

// $Log: nukeapi.php,v $
// Revision 1.10.2.1  2004/01/11 18:35:44  hdonner
// - Fix: 1341
//
// Revision 1.10  2003/12/31 17:02:53  hdonner
// - User: OOP-API
//
// Revision 1.9  2003/12/11 16:23:47  hdonner
// - Zentrierung bei message_box entfernt.
//
// Revision 1.8  2003/12/08 17:56:54  hdonner
// - berflssiges gelscht
//
// Revision 1.7  2003/12/08 16:41:43  hdonner
// - Themes-Backcore angepasst
//
// Revision 1.6  2003/12/06 19:01:40  hdonner
// - Kleine Fixes
//
// Revision 1.5  2003/12/05 21:49:37  hdonner
// - Umstellung bei dem Zugriff auf die Konfigurationsvariablen
//
// Revision 1.4  2003/11/26 20:02:31  hdonner
// - is_user angepasst
//
// Revision 1.3  2003/11/26 15:04:55  hdonner
// - is_active auf Nexus umgestellt
//
// Revision 1.2  2003/11/20 21:10:47  hdonner
// - Kleine Aenderungen in den DB-Abfragen
//
// Revision 1.1  2003/11/12 19:16:43  hdonner
// - Trennung zwischen API und internen Funktionen
//
//
?>
