<?php
// ----------------------------------------------------------------------
// File: $Id: themes.php,v 1.6 2004/01/02 17:12:50 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * themes.php
 *
 * Diese Datei enthlt die Funktionen, die man zur Themes-Verwaltung
 * bentigt.
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage API
 * @category Themes
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * Dateien einbinden
 * 
 * @ignore
 */
require_once VKP_INCLUDE_DIR . '/classes/vkpthemes.php';

/**
 * VKP_THEMES_DIR 
 *
 * Das Verzeichnis, in dem sich die Themes befinden.
 * 
 * @access private
 */
define('VKP_THEMES_DIR', 'themes');
 
/**
 * vkpThemeGetAll
 *
 * Liefert alle installierten Themes-Namen zurck.
 *
 * @return array
 * @version 0.2
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpThemeGetAll()
{
    static $result;

    if (isset($result))
        return $result;

    $themes =& vkpThemes::GetInstance();
    $result =& $themes->GetAllAsReference();
    return $result;
}

/**
 * vkpThemeGetCurrent
 *
 * Liefert den Namen des aktuell zu benutzenden Themes zurck.
 *
 * @return string Der Name
 * @version 0.2
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpThemeGetCurrent()
{
    static $result;
    
    if (isset($result))
        return $result;
    
    $themes =& vkpThemes::GetInstance();
    $result = $themes->default;
    return $result;
}

/**
 * vkpThemeGetDirectory
 *
 * Liefert das Verzeichnis des angegebenen Themes zurck. Diese Funktion
 * ist normal nicht von Bedeutung, sondern lediglich fr den internen
 * Gebrauch gedacht.
 *
 * @param string $name Der Name des Themes
 * @param bool $absolute Wenn TRUE, dann wird der absolute Pfad zurckgegeben
 * @return string Das Verzeichnis
 * @version 0.2
 * @since 5.5.1
 * @author Hinrich Donner
 * @access protected
 */
function vkpThemeGetDirectory($name, $absolute = false)
{
    if ($absolute)
        $result = realpath('themes/' . vkpVarPrepForOs($name));
    else
        $result = 'themes/' . vkpVarPrepForOs($name);
    return $result;
}

/**
 * vkpThemeLanguageReplace
 *
 * Ersetzt Konstanten aus den HTML-Dateien mit den tatschlichen
 * Konstanten.
 *
 * @param string $token Der Name der Konstanten
 * @return string Der Wert oder eine Fehlermeldung als HTML-Kommentar
 * @version 0.1
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpThemeLanguageReplace($token)
{
    static $constants;

    if (!isset($constants))
        $constants = get_defined_constants();

    if (array_key_exists($token, $constants))
        return $constants[$token];

    return "&nbsp;<!-- '$token' is not defined! -->";
}

/**
 * vkpThemeLanguageLoad
 *
 * Ld die Sprachdatei des Themes.
 *
 * @version 0.1
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpThemeLanguageLoad()
{
    static $loaded;

    if (isset($loaded))
        return;

    $loaded = true;

    global $currentlang;

    $filename = vkpThemeGetDirectory(vkpThemeGetCurrent()) . '/language/lang-' . vkpVarPrepForOs($currentlang) . '.php';
    if (!file_exists($filename))
        return;

    require_once $filename;
}

/**
 * vkpThemeExists
 *
 * Diese Funktion prft, ob das angegebene Theme installiert ist.
 *
 * @param string $name Der Name
 * @return bool TRUE oder FALSE
 * @version 0.2
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpThemeExists($name)
{
    static $themes;
    
    if (!isset($themes))
        $themes =& vkpThemes::GetInstance();
    
    $result = $themes->IsValid($name);
    return $result;
}

/**
 * vkpThemeInclude
 *
 * Diese Funktion bindet das gewhlte Theme ein. Auerdem wird die Datei
 * theme-extension.php eingebunden, die bei Bedarf die Funktionen title(),
 * themepreview() und themecenterbox() definiert.
 *
 * @see vkpThemeGetCurrent()
 * @version 0.2
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpThemeInclude()
{
    static $themes;
    
    if (!isset($themes))
        $themes =& vkpThemes::GetInstance();
    
    $themes->Load();
    return;
}

/**
 * vkpThemeLogoHtmlTag
 *
 * Liefert den HTML-Tag IMG mit dem Logo zurck.  Das Logo muss immer in dem Verzeichnis
 * themes/<ThemeName>/images/ liegen und den Namen logo, logo-easter oder logo-xmas
 * mit der Erweiterung png, jpg, jpeg oder gif haben. In dem Zeitraum von 14 Tagen vor
 * Ostern und Ostermontag wird das Logo logo-easter angezeigt, ab dem Freitag vor dem
 * ersten Advent bis zum zweiten Weihnachtsfeiertag das Logo logo-xmas.
 *
 * @param string $alt Der alternative Text
 * @param bool $xhtml Wenn dieser Wert TRUE ist, wird ein XHTML-konformer Tag zurckgegeben
 * @version 0.1
 * @since 5.5.1
 * @author Hinrich Donner
 * @see vkpThemeEasterActive(), vkpThemeXmasActive()
 */
function vkpThemeLogoHtmlTag($alt = '', $xhtml = false)
{
    $image_path = vkpThemeGetDirectory(vkpThemeGetCurrent()) . '/images';
    $extensions = array('png',
                        'jpg',
                        'jpeg',
                        'gif');
    $filenames  = array();
    if (vkpThemeXmasActive())
        $filenames[] = 'logo-xmas';
    elseif (vkpThemeEasterActive())
        $filenames[] = 'logo-easter';
    $filenames[] = 'logo';

    foreach ($filenames as $filename)
    {
        foreach ($extensions as $extension)
        {
            $image_file = $image_path . '/' . $filename . '.' . $extension;
            if (!file_exists($image_file))
                continue;
            $image_tag = '<img src="' . $image_file . '" ';
            break;
        }
        if (!empty($image_tag))
            break;
    }
    // Nichts gefunden!
    //
    if (empty($image_tag))
        return '';

    // Tag fertig stellen
    //
    $size = getimagesize($image_file);
    $image_tag .= $size[3] . ' alt="' . $alt . '" border="0" hspace="0" vspace="0" class="logo"';
    if ($xhtml)
        $image_tag .= ' /';
    $image_tag .= '>';
    return $image_tag;
}

/**
 * vkpThemeEasterActive
 *
 * Prft, ob die Vorosterzeit erreicht wurde, die 14 Tage vor Ostern umfasst.
 * Als sich das Christentum als Religion im Rmischen Reich durchgesetzt hatte,
 * berief man im Jahre 325 in der Stadt Nikaia eine Konferenz ein, auf der eine
 * christliche Doktrin verabschiedet wurde. Auerdem legte man den Frhlingsanfang
 * auf den Tag fest, an dem der Tag genauso lang ist wie die Nacht. Dies ist der
 * 21. Mrz. Man bestimmte den Zeitpunkt fr Ostern als den Sonntag, der dem
 * ersten Frhlingsvollmond folgt.
 *
 * @return bool TRUE in der Osterzeit (14 Tage), sonst FALSE
 * @version 0.1
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpThemeEasterActive()
{
    static $result;

    if (isset($result))
        return $result;

    $result = false;

    // Ostern berechnen
    //
    $y = date('Y');
    $leap = ((($y % 4) == 0) && ((($y % 100) != 0) || (($y % 400) == 0)));
    $gz = ($y % 19) + 1;
    $jhd = (int) ($y / 100) + 1;
    $ksj = (int) ((3 * $jhd) / 4) - 12;
    $korr = (int) ((8 * $jhd + 5) / 25) - 5;
    $so = (int) ((5 * $y) / 4) - $ksj - 10;
    $epakte = (11 * $gz + 20 + $korr - $ksj) % 30;
    if ((($epakte == 25) && ($gz > 11)) || ($epakte == 24))
        $epakte++;
    $n = 44 - $epakte;
    if ($n < 21)
        $n += 30;
    $n = $n + 7 - ($so + $n) % 7;
    if ($leap)
        $n++;
    $easter_period_start    = $n + 44;
    $easter_period_end      = $n + 59;
    $today = date('z');

    if (($today >= $easter_period_start) && ($today <= $easter_period_end))
        $result = true;
    return $result;
}

/**
 * vkpThemeXmasActive
 *
 * Diese Funktion wird intern benutzt. Sie prft, ob sich das aktuelle Systemdatum
 * zwischen dem Freitag vor dem 1. Advent und dem zweiten Weihnachtsfeiertag befindet.
 * In diesem Fall liefert die Funktion TRUE, sonst immer FALSE.
 *
 * @return bool TRUE in der Advents- und Weihnachtszeit, sonst FALSE
 * @version 0.1
 * @since 5.5.1
 * @author Hinrich Donner
 */
function vkpThemeXmasActive()
{
    static $result;

    if (isset($result))
        return $result;

    $result = false;

    // Weihnachten und Advent berrechnen
    //
    $xmas_eve           = mktime(0, 0, 0, 12, 24, date('Y'));
    $xmas_eve_year_day  = date('z', $xmas_eve);
    $xmas_day           = date('w', $xmas_eve);
    $advent_1_friday    = $xmas_eve_year_day - $xmas_day - 21 - 2;
    $today              = date('z');
    if (($today >= $advent_1_friday) && ($today <= ($xmas_eve_year_day + 2)))
        $result = true;
    return $result;
}

// $Log: themes.php,v $
// Revision 1.6  2004/01/02 17:12:50  hdonner
// - OOP-API Themes
//
// Revision 1.5  2003/12/31 17:01:15  hdonner
// - Fix: Ostern
//
// Revision 1.4  2003/12/11 16:24:34  hdonner
// - Mehrsprachigkeit bei den HTML-Templates implementiert
//
// Revision 1.3  2003/12/10 09:15:13  hdonner
// - Fix: Farbdefinitionen wurden vergessen
//
// Revision 1.2  2003/12/08 16:41:43  hdonner
// - Themes-Backcore angepasst
//
// Revision 1.1  2003/12/07 22:03:54  hdonner
// - themes.php enthaelt die API fuer Theme relevante Dinge
// - vkpThemeLogoHtmlTag() liefert einen HTML-Tag zurueck, um das Logo
//   anzeigen zu koennen. Ostern und Weihnachten werden dabei
//   beruecksichtigt.
//
//
?>
