<?php
// ----------------------------------------------------------------------
// File: $Id: vkplibrary.php,v 1.1.2.1 2004/01/17 22:39:09 hdonner Exp $
// ----------------------------------------------------------------------
// PHP-Nuke-VKP
// Copyright 2001-2004 by PHP-Nuke-VKP-Team
// http://developer.berlios.de/projects/phpnukevkp/
// ----------------------------------------------------------------------
// LICENSE
//
// Dieses Programm ist freie Software; Sie knnen sie beliebig verteilen
// und/oder nderungen vornehmen, solange Sie dieses unter den
// Lizenzbedingungen der Version 2 oder hher der GNU General Public
// License (GPL), verffentlicht von der Free Software Foundation tun.
//
// Dieses Programm wurde in der Hoffnung erstellt, dass es fr Sie
// ntzlich sein knnte. Es wird jedoch ohne jeden Anspruch auf
// Gewhrleistung verffentlicht. Sie knnen auch nicht davon ausgehen,
// dass das Programm Dinge verrichtet, wie es erwartet wird.
//
// Lesen Sie die Lizenzbedinguneg unter der URL
// http://www.gnu.org/copyleft/gpl.html fr weitere Details.
// ----------------------------------------------------------------------

/**
 * vkplibrary.php
 *
 * Diese Datei enthlt die Bibliothek fr das Modul Topics
 *
 * @author Hinrich Donner
 * @version 0.1
 * @since 5.5.1
 * @package PHP-Nuke-VKP
 * @subpackage API
 * @category Themen
 * @link http://developer.berlios.de/projects/phpnukevkp/
 */

/**
 * Topic
 *
 * Diese Klasse dient der Verwaltung der Daten eines einzelnen Themas.
 *
 * @see vkpRecordSet
 */
class Topic extends vkpRecordSet
{
    /**
     * name
     *
     * Diese Eigenschaft enthlt den Namen des Themas.  Ein Zugriff sollte nur
     * lesend erfolgen.
     *
     * @var string
     * @see Topic::GetName(), Topic::SetName()
     */
    var $name = '';

    /**
     * image
     *
     * Der Dateiname des dazugehrigen Bildes.  Der Pfad ist in der Konfiguration
     * gespeichert.
     *
     * @var string
     * @see Topic::GetImage(), Topic::SetImage()
     */
    var $image = '';

    /**
     * description
     *
     * Die Beschreibung des Themas.
     *
     * @var string
     * @see Topic::GetDescription(), Topic::SetDescription()
     */
    var $description = '';

    /**
     * hits
     *
     * Die Anzahl der Zugriffe auf diesen Themenbereich.
     *
     * @var int
     * @see Topic::GetHits(), Topic::IncrementHits()
     */
    var $hits = 0;

    /**
     * Topic
     *
     * Der Konstruktor.
     *
     * @param mixed $copy_from Eine Datenwuelle (Array oder Instanz von Topic)
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function Topic($copy_from = false)
    {
        $this->vkpRecordSet();

        if (false === $copy_from)
            return;

        elseif (is_array($copy_from)
                && array_key_exists('id', $copy_from)
                && array_key_exists('name', $copy_from)
                && array_key_exists('image', $copy_from)
                && array_key_exists('description', $copy_from))
        {
            foreach ($copy_from as $property => $value)
                $this->$property = $value;
        }

        elseif (is_object($copy_from) && is_a($copy_from, 'Topic'))
        {
            $this->id           = $copy_from->id;
            $this->name         = $copy_from->name;
            $this->description  = $copy_from->description;
            $this->image        = $copy_from->image;
            $this->hits         = $copy_from->hits;
        }
    }

    /**
     * GetName
     *
     * Liefert den Namen des Themenbereichs.
     *
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     */
    function GetName()
    {
        return $this->GetProperty('name');
    }

    /**
     * SetName
     *
     * Legt den Namen des Themas fest.
     *
     * @param string $value Der Name
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see Topic::GetName()
     */
    function SetName($value)
    {
        return $this->SetProperty('name', $value);
    }

    /**
     * GetDescription
     *
     * Liefert die Beschreibung des Themenbereichs.
     *
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see Topic::SetDescription()
     */
    function GetDescription()
    {
        return $this->GetProperty('description');
    }

    /**
     * SetDescription
     *
     * Legt die Beschreibung des Themas fest.
     *
     * @param string $value Der Text
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see Topic::GetDescription()
     */
    function SetDescription($value)
    {
        return $this->SetProperty('description', $value);
    }

    /**
     * GetImage
     *
     * Liefert den Namen des Bildes.  Mit $pathtype kann festgelegt werden,
     * wie die Rckgabe erfolgen soll: Voll (also bis zum Root-Directory,
     * relativ zum Web oder nur der Dateiname.
     *
     * @param int $pathtype Art des Dateinamen
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see Topic::SetImage(), PATH_TYPE_FULL, PATH_TYPE_RELATIVE, PATH_TYPE_FILENAME
     */
    function GetImage($pathtype = PATH_TYPE_RELATIVE)
    {
        $imagefile = $this->GetProperty('image');
        switch ($pathtype)
        {
            case PATH_TYPE_FULL:
                $result = VKP_BASE_DIR . '/' . $config->tipath . $imagefile;
                break;

            case PATH_TYPE_FILENAME:
                $result = $imagefile;
                break;

            case PATH_TYPE_RELATIVE:
            default:
                $result = $this->_config->tipath . $imagefile;
                break;
        }
        return $result;
    }

    /**
     * SetImage
     *
     * Legt ein neues Bild fest.
     *
     * @param string $value Der Dateiname (ohne Verzeichnisse)
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see Topic::GetImage()
     */
    function SetImage($value)
    {
        return $this->SetProperty('image', basename($value));
    }

    /**
     * GetHits
     *
     * Liefert die Anzahl der Zugriffe auf den Themenbereich.
     *
     * @return string
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see Topic::IncrementHits()
     */
    function GetHits()
    {
        return $this->GetProperty('hits');
    }

    /**
     * IncrementHits
     *
     * Erhht die Anzahl der Hits.  Diese MEthode greift unmittelbar auf
     * die Tabelle zu.
     *
     * @param int $add Die Anzahl, um die erhht werden soll
     * @return bool
     * @author Hinrich Donner
     * @version 0.1
     * @since 5.5.1
     * @see Topic::GetHits()
     */
    function IncrementHits($add = 1)
    {
        $_add = (int) $add;
        if (empty($add) || ($_add <= 0) || ($this->GetId() == -1))
            return false;

        $sql = "UPDATE `" . $this->_config->prefix . "_topics`
                SET `counter`=`counter`+" . vkpVarPrepForStore($_add) . "
                WHERE `topicid`='" . $this->_PrepForStore('id') . "'";
        if (false == sql_query(&$sql))
            return false;

        $this->hits += $_add;
        return true;
    }
}

// $Log: vkplibrary.php,v $
// Revision 1.1.2.1  2004/01/17 22:39:09  hdonner
// - Topics auf OOP umgestellt
//
//
?>
